@@ -1,14 +1,16 @@
+from typing import Any, Dict
+
 from ..dataclasses import Template
 from .schemas import Template as TemplateSchema
 
 template_schema = TemplateSchema()
 
 
-def dict_to_template(data: dict) -> Template:
+def dict_to_template(data: dict[str, Any]) -> Any:
     return template_schema.load(data)
 
 
-def alt_dict_to_template(data: dict) -> Template:
+def alt_dict_to_template(data: dict[str, Any]) -> Template:
     """
     Note
     ----
@@ -32,5 +34,5 @@ def alt_dict_to_template(data: dict) -> Template:
     )
 
 
-def is_alt_format(data: dict) -> bool:
+def is_alt_format(data: dict[str, Any]) -> bool:
     return data.get("files") is not None
